.. _maskers_ref:

:mod:`nilearn.maskers`: Extracting Signals from Brain Images
============================================================

.. automodule:: nilearn.maskers
   :no-members:
   :no-inherited-members:

**User guide:** See the :ref:`nifti_masker` section for further details.

Classes
-------

.. currentmodule:: nilearn.maskers

.. autosummary::
   :toctree: generated/
   :template: class.rst

   BaseMasker
   NiftiMasker
   MultiNiftiMasker
   NiftiLabelsMasker
   MultiNiftiLabelsMasker
   NiftiMapsMasker
   MultiNiftiMapsMasker
   NiftiSpheresMasker
   SurfaceLabelsMasker
   SurfaceMasker
   SurfaceMapsMasker

.. autoclasstree:: nilearn.maskers
   :full:

.. toctree::

   generated_reports/masker_reports_examples.rst
